



### convert base positions into points on x and y chr for all SNPs and all probes tested
## snps.all is locations of all snps (SNP ID, CHR, BP)
## meth.all is locations of all methylation probes (SNP ID, CHR, BP)

chrEnd.meth<-vector(length = 22)
chrEnd.snps<-vector(length = 22)
for(i in 1:22){
	chrEnd.meth[i]<-max(meth.all[which(meth.all$CHR == i),3])
	chrEnd.snps[i]<-max(snps.all[which(snps.all[,2] == i),3])
}

chrStart.meth<-vector(length = 22)
chrStart.snps<-vector(length = 22)
for(i in 1:22){
	chrStart.meth[i]<-min(meth.all[which(meth.all$CHR == i),3])
	chrStart.snps[i]<-min(snps.all[which(snps.all[,2] == i),3])
}

chrSize.snps<-chrEnd.snps-chrStart.snps
chrSize.meth<-chrEnd.meth-chrStart.meth

snp.coord<-vector(length = nrow(snps.all))
meth.coord<-vector(length = nrow(meth.all))
for(i in 1:22){
	snp.coord[which(snps.all[,2] == i)]<-(snps.all[which(snps.all[,2] == i),3]-chrStart.snps[i])/chrSize.snps[i]+i-1
	meth.coord[which(meth.all[,2] == i)]<-(meth.all[which(meth.all[,2] == i),3]-chrStart.meth[i])/chrSize.meth[i]+i-1
}


snps.all<-cbind(snps.all, snp.coord)
meth.all<-cbind(meth.all, meth.coord)

### convert positions for Bonferroni significant mQTLs into x and y co-ordinates contained in object output.

points.y<-snps.all[match(gsub("_.", "", output$SNP), snps.all[,1]),4]
points.x<-meth.all[match(output$gene, meth.all$TargetID),4]

### take absolute values of effect size
logP<-abs(output$beta)

### see source data for resulting data points.


logP_col_palette<-cbind(seq(from = 0, to = 0.61, by = 0.01) , colorRampPalette(c("tan1", "orange",  "red", "red3", "red4",  "darkred"))(62))


layout(matrix(c(1,2), ncol = 1), height = c(1,0.1))
par(mar = c(10,10,3,1))
par(mgp = c(6,1.5,0))

points.col<-logP_col_palette[match(round(logP,2), logP_col_palette[,1]),2]
plot(points.x, points.y, pch = 15, cex =0.75, col = points.col, type = "n", ylab = "Position of SNP (Chr)", xlab = "Position of DNA methylation site (Chr)", main = "",  axes = FALSE, xlim = c(0,22), ylim = c(0,22), xaxs = "i", yaxs = "i",cex.lab = 4, cex.axis = 4, cex.main = 4)
axis(1, at = c(-1,seq(0.5,21.5, by = 1), 23), c("", 1:22, ""), cex.axis = 3.1)
axis(2, at = c(-1,seq(0.5,21.5, by = 1), 23), c("", 1:22, ""), cex.axis = 3.5, las = 2)
points(points.x[length(points.x):1], points.y[length(points.x):1], pch = 15, cex =0.75, col = points.col[length(points.x):1])


### plot legend
par(mar = c(5,8,1,8))
par(mgp = c(3,2,0))
plot(as.numeric(logP_col_palette[,1]), rep(1, nrow(logP_col_palette)), col = logP_col_palette[,2], pch = 15, cex = 4, axes = FALSE, main  = "", ylab = "", ylim = c(0.9999,1.001),xlab = "", cex.lab = 4, cex.axis = 4, cex.main = 4, adj = 0)
axis(1, at = c(0,0.2,0.4,0.6),  c(0,0.2,0.4,0.6)*100, cex.axis = 3)

