



library(GenomicFeatures)
library(WGCNA)
library(genoPlotR)
library(NCBI2R)
### download gene annotation from UCSC
tmp<-makeTranscriptDbFromUCSC("hg19", "refGene")
cols <- c("gene_id", "tx_id", "tx_name", "tx_chrom", "tx_strand","exon_id", "exon_name", "exon_chrom", "exon_strand", "cds_id", "cds_name","cds_chrom", "cds_strand","exon_rank")
tmp_genes<-as.data.frame(genes(tmp, columns = cols))
tmp_Exons<-as.data.frame(exons(tmp, columns = cols))


tagSNPs<- ### list of tag SNPs for PGC index SNPs
indexsnps<- ### list of PGC2 index SNPs
indexsnps<-indexsnps[,1]
tagSNPs<-tagSNPs[which(tagSNPs %in% indexsnps== FALSE)]  ### remove index SNPs from tag SNPs

indexsnps.loc<- ### chr and base pair position for index snps


palette<-cbind(seq(from = 4, to = 50, by = 1) , colorRampPalette(c("grey",  "blue", "navy"))(47))
palette[,1]<-round(as.numeric(palette[,1]), 2)
ld_palette<-cbind(seq(from = 0.8, to = 1, by = 0.01) , colorRampPalette(c("black", "red"))(21))

out_2<- ### table of PGC2 index and tag SNPs with mQTLs (full imputed version available for download from http://epigenetics.essex.ac.uk/mQTL/



fetal.meth<-  ### contains Probe ID, CHR and BP for all probes that passed QC
fetal.snps.all<-   ### contains SNP ID, CHR and BP for all SNPs that passed QC

### regions to plot
chrs<-c(1, 3, 5,7,10, 12,12, 15,  17,19)
starts<-c(2372401, 52541105, 140023664, 1896096,104585135,29905265	,123448113, 78803032, 17722402,19374022)
stops<-c(2402501, 52903405, 140222664, 2190096,104956335,29940365, 123909113, 78926732, 18030202,19658022)
best<-c(2387101,52845105,140143664,2025096,104612335,29917265, 123665113,78908032 ,17958402,19478022)


LineCexMap<-cbind(seq(from = 0, to = 0.11, by = 0.01), seq(from = 0.5, to = 4, by = 0.318))
LineShadeMap_LD<-cbind(seq(from = 0.8, to = 1, by = 0.01), colorRampPalette(c("gray", "red"))(21))
store<-c()
for(i in 1:length(chrs)){
	chr<-chrs[i]
	start<-starts[i]
	stop<-stops[i]


	## just consider cis effects
	res.tmp<-out_2[which(out_2$CHR == chr & out_2$SNP_Chr == chr & out_2$SNP_BP <= stop+500000 & out_2$SNP_BP >= start-500000),]
	res.tmp<-res.tmp[which(is.na(res.tmp$p.value) == FALSE & res.tmp$p.value < 3.69E-13),]

	if(nrow(res.tmp) > 0 & sum(!is.na(res.tmp$p.value)) > 0){
	all.snps<-as.matrix(unique(cbind(as.character(res.tmp$SNP), res.tmp$SNP_BP)))
	all.meth<-as.matrix(unique(cbind(as.character(res.tmp$gene), res.tmp$MAPINFO)))
	if(nrow(all.snps) > 1){
		all.snps<-all.snps[order(all.snps[,2]),]
	}
	if(nrow(all.meth) > 1){
		all.meth<-as.matrix(all.meth, ncol = 2, nrow = 1)
	}	


	region.start<-min(c(start, as.numeric(all.snps[,2]), as.numeric(all.meth[,2])))-50000
	region.end<-max(c(stop, as.numeric(all.snps[,2]), as.numeric(all.meth[,2])))+50000

	all.tested.snps<-fetal.snps.all[which(fetal.snps.all[,2] == chr & fetal.snps.all[,3] >= region.start & fetal.snps.all[,3] <= region.end),]
	## only mark SNPs tested that are r2 > 0.8
	snps.intersect<-unique(c(intersect(unique(paste(out[,2], out[,3], sep = ":")), all.tested.snps[,1]), intersect(unique(paste(out[,2], out[,4], sep = ":")), all.tested.snps[,1])))
	all.tested.snps<-all.tested.snps[match(snps.intersect, all.tested.snps[,1]),]
	
	all.tested.meth<-fetal.meth[which(fetal.meth$CHR == chr & fetal.meth$MAPINFO >= region.start & fetal.meth$MAPINFO <= region.end),]
	
	### identify gene annotation
	sub.genes<-tmp_genes[which(tmp_genes$seqnames == paste("chr", chr, sep = "") & ((tmp_genes$start >= region.start & tmp_genes$start <= region.end) | (tmp_genes$end <= region.end & tmp_genes$end >= region.start) | (tmp_genes$start <= region.start & tmp_genes$end >= region.end))),]
	sub.genes<-sub.genes[order(sub.genes$start, decreasing = TRUE),]
	##plot each gene on a different line

	pdf("", width = 20, height = (6+nrow(sub.genes)*0.15))

	
	if(nrow(sub.genes) > 0){

	par(mar = c(2,9,1,4))
	par(mgp = c(2,0.7,0))
	plot(0,1, type = "n", ylim = c(0.9,nrow(sub.genes)+3.25), xlim = c(region.start, region.end), axes = FALSE, xlab = "", ylab = "", xaxs = "i")
	names<-GetGeneNames(sub.genes$gene_id)$genesymbol
	for(j in 1:nrow(sub.genes)){
			polygon(c(sub.genes$start[j], sub.genes$end[j],sub.genes$end[j],sub.genes$start[j]), c(j+2.95, j+2.95,  j+3.05,j+3.05), col = "black")
			if(sub.genes$strand[j] == "+"){
				if(sub.genes$end[j]-sub.genes$start[j] > 10000){
				
				for(x0 in seq(sub.genes$start[j]+5000, sub.genes$end[j], 5000)){
					arrows(x0, j+3, x0+100, j+3, length = (0.2-0.00005*nrow(sub.genes)), col = "red")
				}
				} else {
				
					arrows((sub.genes$start[j] + sub.genes$end[j])/2, j+3, ((sub.genes$start[j] + sub.genes$end[j])/2)+100, j+3, col = "red", length = (0.2-0.00005*nrow(sub.genes)))
				}
			} else {
				if(sub.genes$end[j]-sub.genes$start[j] > 10000){
				for(x0 in seq(sub.genes$start[j], (sub.genes$end[j]-5000),  5000)){
					arrows(x0+100, j+3, x0, j+3, length = (0.2-0.00005*nrow(sub.genes)), col = "red")
				}
				} else {
					arrows((sub.genes$start[j] + sub.genes$end[j])/2, j+3, ((sub.genes$start[j] + sub.genes$end[j])/2)-100, j+3, col = "red", length = (0.2-0.00005*nrow(sub.genes)))
				}
			}			
			if((sub.genes$start[j] -30000) <= region.start & sub.genes$end[j] >= region.end){
				axis(2, names[j], at = j+3, las = 2, cex.axis = 1.2,tick = FALSE, line = FALSE,)
			} else {
				if((sub.genes$end[j]+30000) > region.end){
					text(sub.genes$start[j]-100,j+3,names[j], cex = 1.2, pos = 2)
				} else {
					text(sub.genes$end[j]+100,j+3,names[j], cex = 1.2, pos = 4)
				}
			}
			
		sub.exons<-tmp_Exons[which(tmp_Exons$seqnames == sub.genes$seqnames[j] & tmp_Exons$start <= sub.genes$end[j] & tmp_Exons$start >= sub.genes$start[j] & tmp_Exons$end <= sub.genes$end[j] & tmp_Exons$end >= sub.genes$start[j]),]
		sub.exons<-sub.exons[grep( sub.genes$gene_id[[j]], sub.exons$gene_id),]

		if(nrow(sub.exons) > 0){
			for(nExon in 1:nrow(sub.exons)){
				polygon(c(sub.exons$start[nExon], sub.exons$end[nExon],sub.exons$end[nExon],sub.exons$start[nExon]), c(j+2.65, j+2.65,  j+3.25,j+3.25), col = "black")

				}
			}
			
	}
	
	polygon(c(start,stop,stop,start), c(2.65,2.65,3.25,3.25), col = "gray", border = NA)
	segments(best[i], 2.65,best[i], 3.25, lend = 1, lwd = 1.25)
	text(best[i], 3.4, indexsnps[which(indexsnps.loc[,1] == chr & indexsnps.loc[,2] == best[i])], pos = 4)
	### annotate SNP locations
	segments(as.numeric(all.tested.snps[,3]), 1.65, as.numeric(all.tested.snps[,3]), 2.25, lend = 1, col = "blue", lwd = 1.25)

	segments(as.numeric(all.snps[,2]), 1.65, as.numeric(all.snps[,2]), 2.25, lend = 1, col = "blue", lwd = 1.25)

	segments(as.numeric(all.tested.meth$MAPINFO), 0.65, as.numeric(all.tested.meth$MAPINFO), 1.25, lend = 1, col = "red", lwd = 1.25)	

	axis(1, at = c(region.start, region.end), labels = c(paste("chr", chr, ":",region.start, sep = ""), region.end), cex.axis = 1.2)

	axis(2, tick = FALSE, line = FALSE, at = 2, "SNPs", col.axis = "blue", cex.axis = 1.2, las = 2)
	axis(2, tick = FALSE, line = FALSE, at = 1, "450K Probes", col.axis = "red", cex.axis = 1.2, las = 2)
	axis(2, tick = FALSE, line = FALSE, at = 3, "SCZ GWAS signal", cex.axis = 1.2, las = 2)	

} else{

	par(mar = c(2,9,1,4))
	par(mgp = c(2,0.7,0))
	plot(0,1, type = "n", ylim = c(0.9,3.25), xlim = c(region.start, region.end), axes = FALSE, xlab = "", ylab = "", xaxs = "i")

	polygon(c(start,stop,stop,start), c(2.65,2.65,3.25,3.25), col = "gray", border = NA)
	segments(best[i], 2.65,best[i], 3.25, lend = 1, lwd = 1.25)
	### annotate SNP locations
	segments(as.numeric(all.snps[,2]), 1.65, as.numeric(all.snps[,2]), 2.25, lend = 1, col = "blue", lwd = 1.25)
	### annotate probe locations
	segments(as.numeric(all.meth[,2]), 0.65, as.numeric(all.meth[,2]), 1.25, lend = 1, col = "red", lwd = 1.25)	

	axis(1, at = c(region.start, region.end), labels = c(paste("chr", chr, ":",region.start, sep = ""), region.end), cex.axis = 1.2, tick = FALSE)

	axis(2, tick = FALSE, line = FALSE, at = 2, "SNPs", col.axis = "blue", cex.axis = 1.2, las = 2)
	axis(2, tick = FALSE, line = FALSE, at = 1, "450K Probes", col.axis = "red", cex.axis = 1.2, las = 2)
	axis(2, tick = FALSE, line = FALSE, at = 3, "SCZ GWAS signal", cex.axis = 1.2, las = 2)		
}

	for(line in 1:nrow(res.tmp)){
		if(is.na(res.tmp$p.value[line]) != TRUE & res.tmp$p.value[line] < 3.69E-13){
			lines(x = c(res.tmp$SNP_BP[line], res.tmp$MAPINFO[line]), y = c(2,1), lwd = LineCexMap[match(signif(abs(res.tmp$beta[line]), 1), LineCexMap[,1]),2])
		}
	}
	dev.off()
	}
	
}